Crate libpam_sys_helpers

Crate libpam_sys_helpers 

This package contains helpers to deal with memory management and annoying type stuff in libpam-sys (and LibPAM in general).

Structs

BinaryPayload
The structure of the “binary message” payload for the PAM_BINARY_PROMPT extension from Linux-PAM.
OwnedBinaryPayload
A binary message owned by some storage.
PtrPtrVec
A pointer-to-pointer-to-message container for PAM’s conversation callback.
TooBigError
Error returned when attempting to allocate a buffer that is too big.

Traits

Buffer
A trait wrapping memory management.