OwnedBinaryPayload

Struct OwnedBinaryPayload 

pub struct OwnedBinaryPayload<Owner: Buffer>(/* private fields */);
A binary message owned by some storage.

This is an owned, memory-managed version of BinaryPayload. The O type manages the memory where the payload lives. Vec<u8> is one such manager and can be used when ownership of the data does not need to transit through PAM.

Implementations

Source

impl<O: Buffer> OwnedBinaryPayload<O>

pub fn new(data: &[u8], type_: u8) -> Result<Self, TooBigError>

Allocates a new OwnedBinaryPayload.

This will return a TooBigError if you try to allocate too much (more than BinaryPayload::MAX_SIZE).

pub fn contents(&self) -> (&[u8], u8)

The contents of the buffer.

pub fn total_bytes(&self) -> usize

The total bytes needed to store this, including the header.

pub fn into_inner(self) -> O

Unwraps this into the raw storage backing it.

pub fn as_ptr(&self) -> *const BinaryPayload

Gets a const pointer to the start of the message’s buffer.

pub fn into_ptr(self) -> NonNull<BinaryPayload>

Consumes ownership of this message and converts it to a raw pointer to the start of the message.

To clean this up, you should eventually pass it into Self::from_ptr with the same O ownership type.

pub unsafe fn from_ptr(ptr: NonNull<BinaryPayload>) -> Self

Takes ownership of the given pointer.

Safety

You must provide a valid pointer, allocated by (or equivalent to one allocated by) Self::new. For instance, passing a pointer allocated by malloc to OwnedBinaryPayload::<Vec<u8>>::from_ptr is not allowed.