pub struct TooBigError {
pub size: usize,
pub max: usize,
}Expand description
Error returned when attempting to allocate a buffer that is too big.
This is specifically used in OwnedBinaryPayload when you try to allocate
a message larger than 232 bytes.
Fields
size: usizemax: usizeTrait Implementations
Sourceimpl Debug for TooBigError
impl Debug for TooBigError
Sourceimpl Display for TooBigError
impl Display for TooBigError
Sourceimpl Error for TooBigError
impl Error for TooBigError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for TooBigError
impl PartialEq for TooBigError
Sourcefn eq(&self, other: &TooBigError) -> bool
fn eq(&self, other: &TooBigError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TooBigError