This package contains helpers to deal with memory management and
annoying type stuff in libpam-sys (and LibPAM in general).
Structs
- Binary
Payload - The structure of the “binary message” payload for the
PAM_BINARY_PROMPTextension from Linux-PAM. - Owned
Binary Payload - A binary message owned by some storage.
- PtrPtr
Vec - A pointer-to-pointer-to-message container for PAM’s conversation callback.
- TooBig
Error - Error returned when attempting to allocate a buffer that is too big.
Traits
- Buffer
- A trait wrapping memory management.